@@ -4,7 +4,9 @@ use warnings; use strict;
 
 { package Xporter;
 	use warnings; use strict;
-	our $VERSION='0.0.9';
+	our $VERSION='0.0.10';
+	# 0.0.10 - Remove P from another test (missed one);  Having to use
+	#         replacement lang features is torture  on my RSI
 	# 0.0.9 - add alternate version format for ExtMM(this system sucks)
 	#       - remove diagnostic messages from tests (required P)
 	# 0.0.8 - add current dep for BUILD_REQ of ExtMM
@@ -39,7 +41,7 @@ use warnings; use strict;
 		my $i=0;
 		while($i<@$v2 && $i<@$v1) {
 			my $r = $v1->[$i] cmp $v2->[$i];
-			return $r if $r<0;
+			return 1 if $r>=0;
 			++$i;
 		}
 		return 0;
@@ -49,15 +51,17 @@ use warnings; use strict;
 
 	sub import { 
 		my $pkg			= shift;
-		my $caller	= (caller)[0];
+		my ($caller, $fl, $ln)	= (caller);
 
 		if (@_ && $_[0] =~ /^v?([\d\._]+)$/) {
 			my $verwanted = $1;
 			my @v1=split /_|\./, $verwanted;
 			my @v2=split /_|\./, $VERSION;
-			if (cmp_ver(\@v1, \@v2) <0 ) {
+				if (cmp_ver(\@v1, \@v2) < 0 ) {
 				require Carp; 
-				Carp::croak("Version $verwanted was asked for while this is version $VERSION");
+				Carp::croak(sprintf "File %s at line %s wanted version".
+				" %s of %s. ".
+				"	We have version %s.\n", $fl, $ln, $verwanted, $pkg, $VERSION);
 			}
 			shift;
 		}
@@ -126,7 +130,7 @@ Xporter - Alternative Exporter with persistant defaults & auto-ISA
 
 =head1 VERSION
 
-Version "0.0.9"
+Version "0.0.10"
 
 
 =head1 SYNOPIS
